# encoding: utf-8

from datetime import datetime as _dt

TZ_ADJUST = (_dt.now() - _dt.utcnow()).seconds

ONE_SECOND = 1
FIVE_SECONDS = 5 * ONE_SECOND
TEN_SECONDS = 10 * ONE_SECOND
FIFTEEN_SECONDS = 15 * ONE_SECOND
TWENTY_SECONDS = 20 * ONE_SECOND
TWENTY_FIVE_SECONDS = 25 * ONE_SECOND
THIRTY_SECONDS = 30 * ONE_SECOND
THIRTY_FIVE_SECONDS = 35 * ONE_SECOND
FORTY_FIVE_SECONDS = 45 * ONE_SECOND
FIFTY_SECONDS = 50 * ONE_SECOND
FIFTY_FIVE_SECONDS = 55 * ONE_SECOND
SIXTY_SECONDS = 60 * ONE_SECOND

ONE_MINUTE = SIXTY_SECONDS
FIVE_MINUTES = 5 * ONE_MINUTE
TEN_MINUTES = 2 * FIVE_MINUTES
FIFTEEN_MINUTES = 3 * FIVE_MINUTES
THIRTY_MINUTES = 2 * FIFTEEN_MINUTES
FORTY_FIVE_MINUTES = 3 * FIFTEEN_MINUTES

ONE_HOUR = 60 * ONE_MINUTE
TWO_HOURS = 2 * ONE_HOUR
THREE_HOURS = 3 * ONE_HOUR
FOUR_HOURS = 2 * TWO_HOURS
FIVE_HOURS = 5 * ONE_HOUR
SIX_HOURS = 6 * ONE_HOUR
SEVEN_HOURS = 7 * ONE_HOUR
EIGHT_HOURS = 8 * ONE_HOUR
NINE_HOURS = 9 * ONE_HOUR
TEN_HOURS = 10 * ONE_HOUR

TWELVE_HOURS = 12 * ONE_HOUR
EIGHTEEN_HOURS = 18 * ONE_HOUR
TWENTY_FOUR_HOURS = 24 * ONE_HOUR
THIRTY_SIX_HOURS = 36 * ONE_HOUR
FORTY_EIGHT_HOURS = 48 * ONE_HOUR

ONE_DAY = TWENTY_FOUR_HOURS
TWO_DAYS = 2 * ONE_DAY

ONE_WEEK = 7 * ONE_DAY
TWO_WEEKS = 2 * ONE_WEEK

# Constants below here are all based on multiples of one week so may not be exact

ONE_MONTH = 4 * ONE_WEEK
THREE_MONTHS = 13 * ONE_WEEK
SIX_MONTHS = 26 * ONE_WEEK
NINE_MONTHS = 39 * ONE_WEEK

ONE_YEAR = 52 * ONE_WEEK
